==> sampler-6.x-1.0.tar.gz: sampler/sampler_example/metrics/SamplerExampleMetricVocabularyTermsOnNodes.class.php <==
<?php


/**
 * @file
 * Class for the vocabulary_terms_on_nodes metric.
 */

class  SamplerExampleMetricVocabularyTermsOnNodes extends SamplerMetric {

  public function computeSample() {
    if (module_exists('taxonomy')) {
      // Load options.
      $sample = $this->currentSample;

      $object_ids = $sample->options['object_ids'];

      // The query below doesn't return rows when a vocabulary isn't on any
      // nodes, so fill in starting values of 0 for all relevant vocabularies
      // here so something will always be reported back.
      if (empty($object_ids)) {
        $vids = $this->trackObjectIDs();
      }
      else {
        $vids = $object_ids;
      }
      foreach ($vids as $vid) {
        $this->currentSample->values[$vid]['nodes'] = 0;
      }

      $where = '';
      $args = array($sample->sample_startstamp, $sample->sample_endstamp);
      // If a list of vocabulary IDs has been passed, restrict the sample to
      // those in the list.
      if (!empty($object_ids)) {
        $where = " AND td.vid IN (". db_placeholders($object_ids) .")";
        $args = array_merge($args, $object_ids);
      }

      $result = db_query("SELECT td.vid, COUNT(tn.nid) AS count FROM {term_data} td INNER JOIN {term_node} tn ON td.tid = tn.tid INNER JOIN {node} n ON tn.nid = n.nid WHERE n.created > %d AND n.created < %d$where GROUP BY td.vid", $args);
      while ($data = db_fetch_object($result)) {
        $this->currentSample->values[$data->vid]['nodes'] = $data->count;
      }
    }
  }

  public function trackObjectIDs() {
    $vids = array();
    if (module_exists('taxonomy')) {
      // Each vocabulary is an object to take samples for.
      $vids = array_keys(taxonomy_get_vocabularies());
    }
    return $vids;
  }
}

==> sampler-6.x-1.2.tar.gz: sampler/sampler_example/metrics/SamplerExampleMetricVocabularyTermsOnNodes.class.php <==
<?php


/**
 * @file
 * Class for the vocabulary_terms_on_nodes metric.
 */

class  SamplerExampleMetricVocabularyTermsOnNodes extends SamplerMetric {

  public function computeSample() {
    if (module_exists('taxonomy')) {
      // Load options.
      $sample = $this->currentSample;

      $object_ids = $sample->options['object_ids'];

      // The query below doesn't return rows when a vocabulary isn't on any
      // nodes, so fill in starting values of 0 for all relevant vocabularies
      // here so something will always be reported back.
      if (empty($object_ids)) {
        $vids = $this->trackObjectIDs();
      }
      else {
        $vids = $object_ids;
      }
      foreach ($vids as $vid) {
        $this->currentSample->values[$vid]['nodes'] = 0;
      }

      $where = '';
      $args = array($sample->sample_startstamp, $sample->sample_endstamp);
      // If a list of vocabulary IDs has been passed, restrict the sample to
      // those in the list.
      if (!empty($object_ids)) {
        $where = " AND td.vid IN (". db_placeholders($object_ids) .")";
        $args = array_merge($args, $object_ids);
      }

      $result = db_query_slave("SELECT td.vid, COUNT(tn.nid) AS count FROM {term_data} td INNER JOIN {term_node} tn ON td.tid = tn.tid INNER JOIN {node} n ON tn.nid = n.nid WHERE n.created > %d AND n.created < %d$where GROUP BY td.vid", $args);
      while ($data = db_fetch_object($result)) {
        $this->currentSample->values[$data->vid]['nodes'] = $data->count;
      }
    }
  }

  public function trackObjectIDs() {
    $vids = array();
    if (module_exists('taxonomy')) {
      // Each vocabulary is an object to take samples for.
      $vids = array_keys(taxonomy_get_vocabularies());
    }
    return $vids;
  }
}
